************
Contributors
************

Core Developers
===============
* Riley X. Brady (`github <https://github.com/bradyrx/>`__)
* Aaron Spring (`github <https://github.com/aaronspring/>`__)

Contributors
============
* Andrew Huang (`github <https://github.com/ahuang11/>`__)
* Kathy Pegion (`github <https://github.com/kpegion/>`__)

For a list of all the contributions, see the github
`contribution graph <https://github.com/bradyrx/climpred/graphs/contributors>`_.
